dupin.data.aggregate
--------------------

.. rubric:: Overview

.. py:currentmodule:: dupin.data.aggregate

.. autosummary::
    :nosignatures:

    SignalAggregator
    XarrayGenerator

.. rubric:: Details

.. automodule:: dupin.data.aggregate
    :members: SignalAggregator, XarrayGenerator
